@@ -11,6 +11,7 @@ struct LtvFieldInfo {
     ltv_id: u8,
     ident: Option<syn::Ident>,
     ty: syn::Type,
+    is_list: bool
 }
 
 #[derive(Debug)]
@@ -146,27 +147,32 @@ fn impl_ltv_named(
             };
             let full_name = format!("{}::{}", &struct_name, ident_name);
 
-            let ltv_id: u8 = {
-                let ltv_id_lit: LitInt = f
+            let (is_list, ltv_id): (bool, u8) = {
+                let ltv_id_attr = f
                     .attrs
                     .into_iter()
-                    .filter(|e| e.path.is_ident("ltv_field"))
+                    .filter(|e| e.path.is_ident("ltv_field") || e.path.is_ident("ltv_field_list") )
                     .next()
-                    .expect(&format!("{} does not have ltv_field", &full_name))
-                    .parse_args()
+                    .expect(&format!("{} does not have ltv_field or ltv_field_list", &full_name));
+                    
+                let lit_id_lit_args : LitInt = ltv_id_attr.parse_args()
                     .expect(&format!(
                         "{} has invalid field id. Must be a number",
                         &full_name
                     ));
-                ltv_id_lit
+                (
+                    ltv_id_attr.path.is_ident("ltv_field_list"),
+                    lit_id_lit_args
                     .base10_parse()
                     .expect(&format!("{} has invalid field id.", &full_name))
+                )
             };
 
             LtvFieldInfo {
                 ltv_id,
                 ident: f.ident,
                 ty: f.ty,
+                is_list
             }
         })
         .collect();
@@ -180,10 +186,17 @@ fn impl_ltv_named(
     let field_length_size = attrs.field_length_size.unwrap_or(1) as usize;
 
     let from_ltv_fn = {
-        let ltv_fields = ltv_fields.iter().map(|LtvFieldInfo { ident, ty, ltv_id }| {
-            quote! {
-                #ident: reader.get_item::<#ty>(#ltv_id)?
+        let ltv_fields = ltv_fields.iter().map(|LtvFieldInfo { ident, ty, ltv_id, is_list }| {
+            if *is_list {
+                quote! {
+                    #ident: reader.get_many::<<#ty as LTVItemMany<#byte_order>>::Item, _>(#ltv_id)?
+                }
+            }else{
+                quote! {
+                    #ident: reader.get_item::<#ty>(#ltv_id)?
+                }
             }
+            
         });
 
         quote! {
@@ -200,10 +213,19 @@ fn impl_ltv_named(
     };
 
     let to_ltv_fn = {
-        let ltv_fields = ltv_fields.iter().map(|LtvFieldInfo { ident, ltv_id, .. }| {
-            quote! {
-                buffer.write_ltv(#ltv_id, &self.#ident).ok();
+        let ltv_fields = ltv_fields.iter().map(|LtvFieldInfo { ident, ty, ltv_id, is_list }| {
+            if *is_list{
+                quote! {
+                    for o in <#ty as LTVItemMany<#byte_order>>::get_items(&self.#ident){
+                        buffer.write_ltv(#ltv_id, o).ok();
+                    }
+                }
+            }else{
+                quote! {
+                    buffer.write_ltv(#ltv_id, &self.#ident).ok();
+                }
             }
+            
         });
 
         quote! {
@@ -234,8 +256,6 @@ fn impl_ltv_named(
     let e = quote! {
         #[automatically_derived]
         impl LTVItem<#byte_order> for #st_name {
-            type Item = Self;
-
             #from_ltv_fn
             #to_ltv_fn
         }
@@ -283,8 +303,6 @@ fn impl_ltv_unnamed(
     let e = quote! {
         #[automatically_derived]
         #byte_order_impl for #struct_ident {
-            type Item = Self;
-
             fn to_ltv(&self) -> Vec<u8>{
                 <#field as LTVItem<#byte_order>>::to_ltv(&self.0)
             }
@@ -296,7 +314,7 @@ fn impl_ltv_unnamed(
     };
 
     //use std::fs;
-    //fs::write(format!("object_impl_{}.rs", &struct_name), e.to_string()).ok();
+    //fs::write(format!("object_impl_unnamed_{}.rs", &struct_name), e.to_string()).ok();
     e
 }
 
